Font

Struct Font 

pub struct Font { /* private fields */ }
A parsed font

Implementations

Source

impl Font

pub fn default_ref() -> &'static Self

Returns a static reference to the default font

This is equivalent to calling Default::default but returns a reference and avoids cloning any internal data

pub fn from_ttf(data: Vec<u8>) -> Result<Self>

Parse a font from TrueType or OpenType format font data

Errors

If there is an error parsing the font data

pub fn family(&self) -> &String

The font family name

Returns "unknown" if the font does not specify a family name

pub fn name(&self) -> &String

The font’s full name

Returns "unknown" if the font does not specify a full name

pub fn em_size(&self) -> f64

The number font units per EM

pub fn cap_height(&self) -> f64

The capital height in font units

Measures the height of the uppercase 'M' if it is not set. In case the font does not contain an uppercase 'M', a default value is returned

pub fn x_height(&self) -> f64

The x-height in font units

Measures the height of the lowercase 'x' if it is not set. In case the font does not contain a lowercase 'x', a default value is returned

pub fn ascender(&self) -> f64

The font’s ascender in font units

pub fn descender(&self) -> f64

The font’s descender in font units

pub fn line_gap(&self) -> f64

The font’s line gap in font units

pub fn line_height(&self) -> f64

The font’s line height in font units

This is equal to self.ascender() + self.descender() + self.line_gap()

pub fn slope(&self) -> Option<f64>

The font’s slope angle in clockwise degrees if specified

pub fn num_glyphs(&self) -> usize

The number of glyph outlines in the font

pub fn glyph(&self, char: char) -> Option<Glyph>

Returns the flyph for a given character if present in the font

pub fn glyph_or_default(&self, char: char) -> Glyph

Returns the glyph for a given character, or the default replacement character if not present

pub fn notdef(&self) -> Glyph

Returns the font’s default replacement glyph, .notdef, or a builtin default if not present

pub fn kerning(&self, left: char, right: char) -> f64

Returns the kerning between two characters’ glyphs, or 0 if no kerning is specified in the font